@@ -1,3 +1,4 @@
+/* exported enable disable */
 /* Screenshot Window Sizer for Gnome Shell
  *
  * Copyright (c) 2013 Owen Taylor <otaylor@redhat.com>
@@ -18,21 +19,16 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-const Gio = imports.gi.Gio;
-const Meta = imports.gi.Meta;
-const Shell = imports.gi.Shell;
-const St = imports.gi.St;
+const { Meta, Shell, St } = imports.gi;
 
 const Main = imports.ui.main;
 const Tweener = imports.ui.tweener;
 
 const ExtensionUtils = imports.misc.extensionUtils;
-const Me = ExtensionUtils.getCurrentExtension();
-const Convenience = Me.imports.convenience;
 
 const MESSAGE_FADE_TIME = 2;
 
-let text, button;
+let text;
 
 function hideMessage() {
     text.destroy();
@@ -54,11 +50,12 @@ function flashMessage(message) {
     text.set_position(monitor.x + Math.floor(monitor.width / 2 - text.width / 2),
                       monitor.y + Math.floor(monitor.height / 2 - text.height / 2));
 
-    Tweener.addTween(text,
-                     { opacity: 0,
-                       time: MESSAGE_FADE_TIME,
-                       transition: 'easeOutQuad',
-                       onComplete: hideMessage });
+    Tweener.addTween(text, {
+        opacity: 0,
+        time: MESSAGE_FADE_TIME,
+        transition: 'easeOutQuad',
+        onComplete: hideMessage
+    });
 }
 
 let SIZES = [
@@ -66,29 +63,27 @@ let SIZES = [
     [800, 450],
     [1024, 576],
     [1200, 675],
-    [1600, 900]
+    [1600, 900],
+    [360, 654], // Phone portrait maximized
+    [720, 360] // Phone landscape fullscreen
 ];
 
-function cycleScreenshotSizes(display, screen, window, binding) {
+function cycleScreenshotSizes(display, window, binding) {
     // Probably this isn't useful with 5 sizes, but you can decrease instead
     // of increase by holding down shift.
     let modifiers = binding.get_modifiers();
     let backwards = (modifiers & Meta.VirtualModifier.SHIFT_MASK) != 0;
 
     // Unmaximize first
-    if (window.maximized_horizontally || window.maximizedVertically)
-        window.unmaximize(Meta.MaximizeFlags.HORIZONTAL | Meta.MaximizeFlags.VERTICAL);
+    if (window.get_maximized() != 0)
+        window.unmaximize(Meta.MaximizeFlags.BOTH);
 
     let workArea = window.get_work_area_current_monitor();
     let outerRect = window.get_frame_rect();
 
     // Double both axes if on a hidpi display
     let scaleFactor = St.ThemeContext.get_for_stage(global.stage).scale_factor;
-    let scaledSizes = SIZES.map(function(size) {
-        return size.map(function(wh) {
-            return wh * scaleFactor;
-        });
-    });
+    let scaledSizes = SIZES.map(size => size.map(wh => wh * scaleFactor));
 
     // Find the nearest 16:9 size for the current window size
     let nearestIndex;
@@ -128,8 +123,8 @@ function cycleScreenshotSizes(display, screen, window, binding) {
 
     let newOuterRect = window.get_frame_rect();
     let message = '%d×%d'.format(
-            (newOuterRect.width / scaleFactor),
-            (newOuterRect.height / scaleFactor));
+        (newOuterRect.width / scaleFactor),
+        (newOuterRect.height / scaleFactor));
 
     // The new size might have been constrained by geometry hints (e.g. for
     // a terminal) - in that case, include the actual ratio to the message
@@ -141,17 +136,14 @@ function cycleScreenshotSizes(display, screen, window, binding) {
     flashMessage(message);
 }
 
-function init() {
-}
-
 function enable() {
     Main.wm.addKeybinding('cycle-screenshot-sizes',
-                          Convenience.getSettings(),
+                          ExtensionUtils.getSettings(),
                           Meta.KeyBindingFlags.PER_WINDOW,
                           Shell.ActionMode.NORMAL,
                           cycleScreenshotSizes);
     Main.wm.addKeybinding('cycle-screenshot-sizes-backward',
-                          Convenience.getSettings(),
+                          ExtensionUtils.getSettings(),
                           Meta.KeyBindingFlags.PER_WINDOW |
                           Meta.KeyBindingFlags.IS_REVERSED,
                           Shell.ActionMode.NORMAL,
